# Factful.py

A Package which can give you Random Facts in an easy way!

# Links
- [Discord Support Server](https://discord.com/invite/FrduEZd)
- [GitHub Profile](https://github.com/Scientific-Guy)
- [Factful.js NPM](https://www.npmjs.com/package/factful.py.js)

# Quick Example

#### 1. Getting Random Facts

```py
# Import factful.py Module
import factful

# Define facts function
facts = factful.facts()

# Getting random fact from random cateogary
print(facts["all"])

# Getting random facts from a paticular cateogary!
# All Cateogaries: "computer", "food", "emoji", "space"
print(facts["computer"])
print(facts["food"])
print(facts["emoji"])
print(facts["space"])
```

> We also have this module as **Javascript NPM Package**! [https://www.npmjs.com/package/factful.js](https://www.npmjs.com/package/factful.js). You can join our Discord Server for support!

### © Science Spot | Decimal Development - 2020